.. punchbowl documentation master file, created by
   sphinx-quickstart on Fri Nov 10 00:25:21 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to punchbowl's documentation!
=====================================

- We recommend beginning with the introduction and working through the related concepts.
- Check out tutorials for examples of performing specific tasks.
- To understand a specific part of the pipeline, look in the segment descriptions.
- Explore the full API for full details on functions.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   intro
   data/index
   pipeline/index
   auto_examples/index
   help
   contribute

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
